#include <iostream>
#include <qstring.h>
#include <qptrlist.h>
#include <qtextstream.h>
#include <qfile.h>

using std::cout;
using std::endl;

#include "chemdata.h"
#include "dpoint.h"
#include "text.h"
#include "defs.h"


using std::cout;

bool ChemData::load_mdl(QString fn) {
  return false;
}

bool ChemData::ProcessMDL(QString wf) {
  return false;
}

bool ChemData::save_mdl(QString fn) {
  return false;
}
